# HeliosEthernetSilaaCooling

This package was written to set and read the different control-values of a
Helios KWL EC 170 W over Modbus TCP/IP.

It uses the module "easymodbus_SilaaCooling" which is a modified package based
on the package "EasyModbus" by Stefan Rossmann from "Rossmann Engneering".

If you want to support the original release by Stefan Rossmann, check out his
github under
[Github-flavored Markdown](https://github.com/rossmann-engineering/EasyModbusTCP.PY)
or his website http://easymodbustcp.net/en/

For more information and support visit the given gogs-repository under "https://gogs.es-lab.de/SilaaCooling/Simulationsmodell_SilaaCooling/src/master/Helios%20Modbus"
